@@ -73,15 +73,15 @@ static const gchar * status_strings [STATUS_PROVIDER_STATUS_LAST] = {
 };
 
 static const gchar * status_icons[STATUS_PROVIDER_STATUS_LAST] = {
-  /* STATUS_PROVIDER_STATUS_ONLINE, */     "user-available",
-  /* STATUS_PROVIDER_STATUS_AWAY, */       "user-away",
-  /* STATUS_PROVIDER_STATUS_DND, */        "user-busy",
-  /* STATUS_PROVIDER_STATUS_INVISIBLE, */  "user-invisible",
-  /* STATUS_PROVIDER_STATUS_OFFLINE */     "user-offline",
-  /* STATUS_PROVIDER_STATUS_DISCONNECTED */"user-offline"
+  /* STATUS_PROVIDER_STATUS_ONLINE, */     "user-available-panel",
+  /* STATUS_PROVIDER_STATUS_AWAY, */       "user-away-panel",
+  /* STATUS_PROVIDER_STATUS_DND, */        "user-busy-panel",
+  /* STATUS_PROVIDER_STATUS_INVISIBLE, */  "user-invisible-panel",
+  /* STATUS_PROVIDER_STATUS_OFFLINE */     "user-offline-panel",
+  /* STATUS_PROVIDER_STATUS_DISCONNECTED */"user-offline-panel"
 };
 
-static GwibberService * gwibber = NULL;
+static MeGwibberService * me_gwibber_service = NULL;
 
 static DbusmenuMenuitem * root_menuitem = NULL;
 static DbusmenuMenuitem * status_menuitems[STATUS_PROVIDER_STATUS_LAST] = {0};
@@ -136,6 +136,11 @@ status_update (void) {
       dbusmenu_menuitem_property_set_bool(status_menuitems[i],
                                           DBUSMENU_MENUITEM_PROP_ENABLED,
                                           FALSE);
+      dbusmenu_menuitem_property_set_int (status_menuitems[i],
+                                          DBUSMENU_MENUITEM_PROP_TOGGLE_STATE,
+                                          (i != STATUS_PROVIDER_STATUS_OFFLINE)
+                                          ? DBUSMENU_MENUITEM_TOGGLE_STATE_UNCHECKED
+                                          : DBUSMENU_MENUITEM_TOGGLE_STATE_CHECKED);
     }
     return;
   }
@@ -170,7 +175,7 @@ status_update (void) {
 }
 
 static void
-gwibber_status_update (GwibberService *instance, GwibberServiceStatus status, gpointer data) {
+me_gwibber_status_update (MeGwibberService *instance, MeGwibberServiceStatus status, gpointer data) {
   g_return_if_fail (instance != NULL);
 
   g_debug ("gwibber service status changed to: %d", status);
@@ -180,7 +185,7 @@ gwibber_status_update (GwibberService *instance, GwibberServiceStatus status, gp
     return;
   }
 
-  if (! gwibber_service_has_configured_accounts (instance)) {
+  if (! me_gwibber_service_has_configured_accounts (instance)) {
     g_debug ("no configured accounts detected, so hiding the broadcast field");
     dbusmenu_menuitem_property_set_bool (broadcast_field, DBUSMENU_MENUITEM_PROP_VISIBLE, FALSE);
     return;
@@ -189,15 +194,7 @@ gwibber_status_update (GwibberService *instance, GwibberServiceStatus status, gp
   if (! dbusmenu_menuitem_property_get_bool (broadcast_field, DBUSMENU_MENUITEM_PROP_VISIBLE))
     dbusmenu_menuitem_property_set_bool (broadcast_field, DBUSMENU_MENUITEM_PROP_VISIBLE, TRUE);
 
-#if 0
-  if (status == GWIBBER_SERVICE_STATUS_RUNNING) {
-    g_debug ("enabling the broadcast field");
-    dbusmenu_menuitem_property_set_bool (broadcast_field, DBUSMENU_MENUITEM_PROP_ENABLED, TRUE);
-  } else {
-    g_debug ("disabling the broadcast field");
-    dbusmenu_menuitem_property_set_bool (broadcast_field, DBUSMENU_MENUITEM_PROP_ENABLED, FALSE);
-  }
-#endif
+  dbusmenu_menuitem_property_set (broadcast_field, DBUSMENU_ENTRY_MENUITEM_PROP_HINT, me_gwibber_service_get_accounts_string (instance));
 
   return;
 }
@@ -245,32 +242,52 @@ build_accounts_menuitems (gpointer data)
 	DbusmenuMenuitem * root = DBUSMENU_MENUITEM(data);
 	g_return_if_fail(root != NULL);
 
+  DbusmenuMenuitem *im_accounts_mi = NULL;
+  DbusmenuMenuitem *tw_accounts_mi = NULL;
+  DbusmenuMenuitem *u1_accounts_mi = NULL;
+  gboolean at_least_one = FALSE;
+
   if (program_is_installed ("empathy-accounts")) {
-    DbusmenuMenuitem *im_accounts_mi = dbusmenu_menuitem_new();
+    im_accounts_mi = dbusmenu_menuitem_new();
     dbusmenu_menuitem_property_set(im_accounts_mi, DBUSMENU_MENUITEM_PROP_LABEL,
                                    _("Chat Accounts..."));
-    dbusmenu_menuitem_child_append(root, im_accounts_mi);
     g_signal_connect(G_OBJECT(im_accounts_mi), DBUSMENU_MENUITEM_SIGNAL_ITEM_ACTIVATED,
                      G_CALLBACK(spawn_on_activate_cb), "empathy-accounts");
+    at_least_one = TRUE;
   }
 
   if (program_is_installed ("gwibber-accounts")) {
-    DbusmenuMenuitem *tw_accounts_mi = dbusmenu_menuitem_new();
+    tw_accounts_mi = dbusmenu_menuitem_new();
     dbusmenu_menuitem_property_set(tw_accounts_mi, DBUSMENU_MENUITEM_PROP_LABEL,
                                    _("Broadcast Accounts..."));
-    dbusmenu_menuitem_child_append(root, tw_accounts_mi);
     g_signal_connect(G_OBJECT(tw_accounts_mi), DBUSMENU_MENUITEM_SIGNAL_ITEM_ACTIVATED,
                      G_CALLBACK(spawn_on_activate_cb), "gwibber-accounts");
+    at_least_one = TRUE;
   }
 
   if (program_is_installed ("ubuntuone-preferences")) {
-    DbusmenuMenuitem *u1_accounts_mi = dbusmenu_menuitem_new();
+    u1_accounts_mi = dbusmenu_menuitem_new();
     dbusmenu_menuitem_property_set(u1_accounts_mi, DBUSMENU_MENUITEM_PROP_LABEL,
                                    _("Ubuntu One..."));
-    dbusmenu_menuitem_child_append(root, u1_accounts_mi);
     g_signal_connect(G_OBJECT(u1_accounts_mi), DBUSMENU_MENUITEM_SIGNAL_ITEM_ACTIVATED,
                      G_CALLBACK(spawn_on_activate_cb), "ubuntuone-preferences");
+    at_least_one = TRUE;
   }
+
+  if (at_least_one) {
+    DbusmenuMenuitem *separator = dbusmenu_menuitem_new();
+    dbusmenu_menuitem_property_set(separator, DBUSMENU_MENUITEM_PROP_TYPE,
+                                   DBUSMENU_CLIENT_TYPES_SEPARATOR);
+    dbusmenu_menuitem_child_append(root, separator);
+
+    if (im_accounts_mi)
+      dbusmenu_menuitem_child_append(root, im_accounts_mi);
+    if (tw_accounts_mi)
+      dbusmenu_menuitem_child_append(root, tw_accounts_mi);
+    if (u1_accounts_mi)
+      dbusmenu_menuitem_child_append(root, u1_accounts_mi);
+  }
+
 }
 
 static gboolean
@@ -287,9 +304,9 @@ build_providers (gpointer data)
 
 	status_update();
 
-  gwibber = gwibber_service_new ();
-  if (gwibber != NULL) {
-    g_signal_connect (G_OBJECT (gwibber), GWIBBER_SERVICE_SIGNAL_STATUS_CHANGED, G_CALLBACK (gwibber_status_update), NULL);
+  me_gwibber_service = me_gwibber_service_get ();
+  if (me_gwibber_service != NULL) {
+    g_signal_connect (G_OBJECT (me_gwibber_service), ME_GWIBBER_SERVICE_SIGNAL_STATUS_CHANGED, G_CALLBACK (me_gwibber_status_update), NULL);
   }
 
   return FALSE;
@@ -336,6 +353,8 @@ display_mode_changed ()
 }
 
 
+/* disabled for this release */
+#if 0
 static void
 avatar_changed_cb (GFileMonitor * monitor, GFile * file, GFile * other_file, GFileMonitorEvent event_type, gpointer user_data)
 {
@@ -352,7 +371,7 @@ avatar_changed_cb (GFileMonitor * monitor, GFile * file, GFile * other_file, GFi
 }
 
 static void
-build_user_item (DbusmenuMenuitem * root)
+build_avatar_item (DbusmenuMenuitem * root)
 {
   useritem = dbusmenu_menuitem_new();
   dbusmenu_menuitem_property_set(useritem, DBUSMENU_ABOUT_ME_MENUITEM_PROP_NAME, g_get_real_name ());
@@ -371,17 +390,15 @@ build_user_item (DbusmenuMenuitem * root)
 
   g_free (filename);
 
-  gchar *gam = g_find_program_in_path("gnome-about-me");
-  if (gam != NULL) {
-    dbusmenu_menuitem_property_set_bool(useritem, DBUSMENU_MENUITEM_PROP_ENABLED, TRUE);
-    g_signal_connect(G_OBJECT(useritem),
-                     DBUSMENU_MENUITEM_SIGNAL_ITEM_ACTIVATED,
-                     G_CALLBACK(spawn_on_activate_cb), "gnome-about-me");
-    g_free(gam);
-  }
+	return;
+}
+#endif
 
-  /* set the menu name */
-  display_mode_changed ();
+static gboolean
+build_menu (gpointer data)
+{
+	DbusmenuMenuitem * root = DBUSMENU_MENUITEM(data);
+	g_return_val_if_fail(DBUSMENU_IS_MENUITEM(root), FALSE);
 
   /* and receive display mode notifications to update it later */
   GConfClient *context = gconf_client_get_default ();
@@ -393,18 +410,13 @@ build_user_item (DbusmenuMenuitem * root)
     g_object_unref (context);
   }
 
-	return;
-}
-
-static gboolean
-build_menu (gpointer data)
-{
-	DbusmenuMenuitem * root = DBUSMENU_MENUITEM(data);
-	g_return_val_if_fail(root != NULL, FALSE);
-
-  build_user_item(root);
+  /* disabled for this release */
+#if 0
+  build_avatar_item(root);
+#endif
 
   broadcast_field = DBUSMENU_MENUITEM (entry_menu_item_new());
+  dbusmenu_menuitem_property_set (broadcast_field, DBUSMENU_ENTRY_MENUITEM_PROP_HINT, _("Post message..."));
   dbusmenu_menuitem_property_set_bool (broadcast_field, DBUSMENU_MENUITEM_PROP_ENABLED, TRUE);
   dbusmenu_menuitem_property_set_bool (broadcast_field, DBUSMENU_MENUITEM_PROP_VISIBLE, FALSE);
   dbusmenu_menuitem_child_append(root, broadcast_field);
@@ -437,12 +449,33 @@ build_menu (gpointer data)
 		g_debug("Built %s", status_strings[i]);
 	}
 
+	build_accounts_menuitems(root);
+
+  /* add a standard "About Me..." menu item at the end of the menu */
 	DbusmenuMenuitem *separator = dbusmenu_menuitem_new();
 	dbusmenu_menuitem_property_set(separator, DBUSMENU_MENUITEM_PROP_TYPE,
                                  DBUSMENU_CLIENT_TYPES_SEPARATOR);
 	dbusmenu_menuitem_child_append(root, separator);
 
-	build_accounts_menuitems(root);
+  useritem = dbusmenu_menuitem_new();
+  dbusmenu_menuitem_property_set(useritem, DBUSMENU_MENUITEM_PROP_LABEL, _("About Me..."));
+  dbusmenu_menuitem_property_set_bool(useritem, DBUSMENU_MENUITEM_PROP_ENABLED, FALSE);
+  dbusmenu_menuitem_property_set_bool(useritem, DBUSMENU_MENUITEM_PROP_VISIBLE, FALSE);
+  dbusmenu_menuitem_child_append(root, useritem);
+
+  gchar *gam = g_find_program_in_path("gnome-about-me");
+  if (gam != NULL) {
+    dbusmenu_menuitem_property_set_bool(useritem, DBUSMENU_MENUITEM_PROP_ENABLED, TRUE);
+    g_signal_connect(G_OBJECT(useritem),
+                     DBUSMENU_MENUITEM_SIGNAL_ITEM_ACTIVATED,
+                     G_CALLBACK(spawn_on_activate_cb), "gnome-about-me");
+    g_free(gam);
+  }
+
+  /* finally set the menu name and update items visibility according
+     to a gconf key
+  */
+  display_mode_changed ();
 
 	return FALSE;
 }
